#######################
Development & community
#######################

Django App Helper is an open-source project.

You don't need to be an expert developer to make a valuable contribution - all you need is a little
knowledge, and a willingness to follow the contribution guidelines.

*******
Nephila
*******

Django App Helper was created by Iacopo Spalletti at `Nephila <https://nephila.it/>`_
and is released under a GNU GENERAL PUBLIC LICENSE.

Nephila is an active supporter of django CMS and its community. Django App Helper is intended to
help make it easier for developers in the django CMS ecosystem to work effectively and create
high quality applications.

Nephila maintains overall control of the `Django App Helper repository
<https://github.com/nephila/django-app-helper>`_.

********************
Standards & policies
********************

Django App Helper is a django CMS application, and shares much of django CMS's standards and
policies.

These include:

* `guidelines and policies
  <http://docs.django-cms.org/en/support-3.0.x/contributing/contributing.html>`_ for contributing
  to the project, including standards for code and documentation
* standards for `managing the project's development
  <http://docs.django-cms.org/en/support-3.0.x/contributing/management.html>`_
* a `code of conduct
  <http://docs.django-cms.org/en/support-3.0.x/contributing/code_of_conduct.html>`_ for community
  activity

Please familiarise yourself with this documentation if you'd like to contribute to
Django App Helper.
